@@ -1140,7 +1140,7 @@ ppFn0 <- function(w.knot, gridmats, L, nknots, ngrid){
 	for(i in 1:ngrid){
 		A <- matrix(gridmats[1:(L*nknots),i], nrow = nknots)
 		R <- matrix(gridmats[L*nknots + 1:(nknots*nknots),i], nrow = nknots)
-		r <- sum.sq(backsolve(R, w.knot, transpose = TRUE))
+		r <- my_sum_seq(backsolve(R, w.knot, transpose = TRUE))
 		w.grid[,i] <- colSums(A * w.knot)
 		lpost.grid[i] <- -(0.5*nknots+0.1)*log1p(0.5*r/0.1) - gridmats[nknots*(L+nknots)+1,i] + gridmats[nknots*(L+nknots)+2,i]		
 	}
@@ -1159,7 +1159,7 @@ ppFn <- function(w.knot, gridmats, L, nknots, ngrid, a.kap){
 	for(i in 1:ngrid){
 		A <- matrix(gridmats[1:(L*nknots),i], nrow = nknots)
 		R <- matrix(gridmats[L*nknots + 1:(nknots*nknots),i], nrow = nknots)
-		r <- sum.sq(backsolve(R, w.knot, transpose = TRUE))
+		r <- my_sum_seq(backsolve(R, w.knot, transpose = TRUE))
 		w.grid[,i] <- colSums(A * w.knot)
 		lpost.grid[i] <- (logsum(-(nknots/2+a.kap[1,])*log1p(0.5*r/ a.kap[2,]) + a.kap[3,] + lgamma(a.kap[1,]+nknots/2)-lgamma(a.kap[1,])-.5*nknots*log(a.kap[2,]))
 						  - gridmats[nknots*(L+nknots)+1,i] + gridmats[nknots*(L+nknots)+2,i])		
@@ -1178,7 +1178,7 @@ sigFn <- function(z, a.sig) return(exp(z/2))
 sigFn.inv <- function(s, a.sig) return(2 * log(s))
 unitFn <- function(u) return(pmin(1 - 1e-10, pmax(1e-10, u)))
 
-sum.sq <- function(x) return(sum(x^2))
+my_sum_seq <- function(x) return(sum(x^2))
 extract <- function(lo, vn) return(lo[[vn]])       # pull out the "vn"th list item
 logmean <- function(lx) return(max(lx) + log(mean(exp(lx - max(lx)))))
 logsum <- function(lx) return(logmean(lx) + log(length(lx)))
